Documentation
¶
Index ¶
- func FormatHTML(html []byte) []byte
- func MarkdownFileToHTML(file string) []byte
- func MarkdownToHTML(md []byte) []byte
- type Artifact
- type Generator
- type GeneratorInfo
- type NullGenerator
- func (ng NullGenerator) Build(io.Writer) error
- func (ng NullGenerator) Configure(Project, *hcl.EvalContext, hcl.Body) error
- func (ng NullGenerator) Export(Project, io.Writer) error
- func (ng NullGenerator) Import(io.Reader) (*Project, error)
- func (ng NullGenerator) Info() GeneratorInfo
- func (ng NullGenerator) Run(io.Writer) error
- type Project
- type Runner
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MarkdownFileToHTML ¶
MarkdownFileToHTML converts a markdown file to HTML. The output is sanitized using bluemonday.
func MarkdownToHTML ¶
MarkdownToHTML converts a markdown byte slice to HTML. The output is sanitized using bluemonday.
Types ¶
type Generator ¶
type Generator interface {
// Info describes the generator.
Info() GeneratorInfo
// Converts the hcl installer block configuration into a more specific form
// understood by this generator.
Configure(Project, *hcl.EvalContext, hcl.Body) error
// Creates the build environment including folders and configuration files
// needed by the generator.
Build(io.Writer) error
// Runs the generator. This may be a no-op for some generators.
Run(io.Writer) error
// Import a platform specific configuration from a reader. The reader will
// probably come from a configuration file like an InnoSetup *.iss file or
// a pkgbuild/productbuild *.xml distribution file. Roundtrip import/export
// is most likely lossy.
Import(io.Reader) (*Project, error)
// Export a platform specific configuration to a writer. Roundtrip
// import/export is most likely lossy.
Export(Project, io.Writer) error
}
An installer generator backend. e.g. InnoSetup on windows or pkgbuild/productbuild on macOS.
type GeneratorInfo ¶
type NullGenerator ¶
type NullGenerator struct {
}
NullGenerator implements paket.Generator. Does nothing. Fails never.
func (NullGenerator) Build ¶
func (ng NullGenerator) Build(io.Writer) error
Configure implements paket.Generator
func (NullGenerator) Configure ¶
func (ng NullGenerator) Configure(Project, *hcl.EvalContext, hcl.Body) error
Export implements paket.Generator
func (NullGenerator) Export ¶
func (ng NullGenerator) Export(Project, io.Writer) error
Import implements paket.Generator
func (NullGenerator) Import ¶
func (ng NullGenerator) Import(io.Reader) (*Project, error)
Run implements paket.Generator
func (NullGenerator) Info ¶
func (ng NullGenerator) Info() GeneratorInfo
Info implements paket.Generator
type Runner ¶
type Runner struct {
WorkDir string
// contains filtered or unexported fields
}
func (*Runner) ReadProject ¶
func (*Runner) RegisterGenerator ¶
func (*Runner) RegisterGenerators ¶
Source Files
¶
Click to show internal directories.
Click to hide internal directories.